@@ -1,10 +1,10 @@
 /* unify -- Change a diff to/from a context diff from/to a unified diff.
    Copyright (C) 1994, 1997, 1998 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 /* From the public domain version 1.1, as found on 1992-12-22 at
    ftp://ftp.uu.net/usenet/comp.sources.misc/volume25/unidiff/part01.Z.
@@ -23,6 +23,7 @@
 #include "system.h"
 #include <getopt.h>
 #include <string.h>
+#include <locale.h>
 
 /* FIXME: Programs should not have such limits.  */
 #define NAME_LENGTH 255
@@ -140,7 +141,7 @@ ensure_name (void)
     return;
 
   if (!*name)
-    error (0, 0, _("Could not find a name for the diff at line %ld"),
+    error (0, 0, _("could not find a name for the diff at line %ld"),
 	   line_number);
   else if (patch_format)
     {
@@ -269,36 +270,32 @@ static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
+    fprintf (stderr, _("try `%s --help' for more information\n"),
 	     program_name);
   else
     {
       fputs (_("\
 unify - Transforms context diffs into unidiffs, or vice-versa.\n"),
 	     stdout);
+      fputs ("\n", stdout);
       printf (_("\
-\n\
 Usage: %s [OPTION]... [FILE]\n"), program_name);
-      fputs (_("\
-\n\
-  -c, --context-diffs    force output to context diffs\n\
-  -e, --echo-comments    echo comments to standard error\n\
-  -o, --old-diffs        output old-style diffs, no matter what\n\
-  -p, --patch-format     generate patch format\n\
-  -P                     same as -p\n\
-  -s, --strip-comments   strip comment lines\n\
-  -u, --unidiffs         force output to unidiffs\n\
-  -U                     same as -p and -u\n\
-  -=, --use-equals       replace spaces by equal signs in unidiffs\n\
-      --help             display this help and exit\n\
-      --version          output version information and exit\n\
-\n\
-If FILE is not specified, read standard input.\n"),
-	     stdout);
-      fputs (_("\
-\n\
-Report bugs to <wdiff-bugs@gnu.org>.\n"),
-	       stdout);
+      fputs ("\n", stdout);
+      fputs (_("  -c, --context-diffs    force output to context diffs\n"), stdout);
+      fputs (_("  -e, --echo-comments    echo comments to standard error\n"), stdout);
+      fputs (_("  -o, --old-diffs        output old-style diffs, no matter what\n"), stdout);
+      fputs (_("  -p, --patch-format     generate patch format\n"), stdout);
+      fputs (_("  -P                     same as -p\n"), stdout);
+      fputs (_("  -s, --strip-comments   strip comment lines\n"), stdout);
+      fputs (_("  -u, --unidiffs         force output to unidiffs\n"), stdout);
+      fputs (_("  -U                     same as -p and -u\n"), stdout);
+      fputs (_("  -=, --use-equals       replace spaces by equal signs in unidiffs\n"), stdout);
+      fputs (_("      --help             display this help then exit\n"), stdout);
+      fputs (_("      --version          display program version then exit\n"), stdout);
+      fputs ("\n", stdout);
+      fputs (_("If FILE is not specified, read standard input.\n"), stdout);
+      fputs ("\n", stdout);
+      fputs (_("Report bugs to <wdiff-bugs@gnu.org>.\n"), stdout);
     }
   exit (status);
 }
@@ -388,13 +385,13 @@ main (int argc, char *const *argv)
   if (optind < argc)
     {
       if (file = fopen (argv[optind], "r"), file == NULL)
-	error (EXIT_FAILURE, errno, _("Unable to open `%s'"), argv[optind]);
+	error (EXIT_FAILURE, errno, _("unable to open `%s'"), argv[optind]);
       optind++;
     }
 
   if (optind < argc)
     {
-      error (0, 0, _("Only one filename allowed"));
+      error (0, 0, _("only one filename allowed"));
       usage (EXIT_FAILURE);
     }
 
@@ -550,7 +547,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 	    if (*cursor != '@')
 	    bad_header:
 	      error (EXIT_FAILURE, 0,
-		     _("Invalid unified diff header at line %ld"),
+		     _("invalid unified diff header at line %ld"),
 		     line_number);
 
 	    old_end = (old_start ? old_start + old_end - 1 : 0);
@@ -592,7 +589,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 
 	    default:
 	      error (EXIT_FAILURE, 0,
-		     _("Malformed unified diff at line %ld"), line_number);
+		     _("malformed unified diff at line %ld"), line_number);
 	    }
 	  add_line (*buffer, 0L, buffer + 1);
 	  if (old_line == old_end && new_line == new_end)
@@ -623,7 +620,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 	    {
 	      if (old_start < 0)
 		error (EXIT_FAILURE, 0,
-		       _("Context diff missing `old' header at line %ld"),
+		       _("context diff missing `old' header at line %ld"),
 		       line_number);
 	      old_end = old_start;
 	      star_in_cdiff = ' ';
@@ -667,7 +664,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 	  if (buffer[1] == '\n')
 	    strcpy (buffer + 1, " \n");
 	  if (buffer[1] != ' ')
-	    error (EXIT_FAILURE, 0, _("Malformed context diff at line %ld"),
+	    error (EXIT_FAILURE, 0, _("malformed context diff at line %ld"),
 		   line_number);
 
 	  switch (*buffer)
@@ -686,7 +683,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 
 	    default:
 	      error (EXIT_FAILURE, 0,
-		     _("Malformed context diff at line %ld"),
+		     _("malformed context diff at line %ld"),
 		     line_number);
 	    }
 	  if (old_line > old_last)
@@ -722,7 +719,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 	    {
 	      if (new_start < 0)
 		error (EXIT_FAILURE, 0,
-		       _("Context diff missing `new' header at line %ld"),
+		       _("context diff missing `new' header at line %ld"),
 		       line_number);
 	      new_end = new_start;
 	    }
@@ -757,7 +754,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 	    strcpy (buffer + 1, " \n");
 	  if (buffer[1] != ' ')
 	    error (EXIT_FAILURE, 0,
-		   _("Malformed context diff at line %ld"), line_number);
+		   _("malformed context diff at line %ld"), line_number);
 
 	  switch (*buffer)
 	    {
@@ -775,7 +772,7 @@ Written by Wayne Davison <davison@borland.com>.\n"),
 
 	    default:
 	      error (EXIT_FAILURE, 0,
-		     _("Malformed context diff at line %ld"), line_number);
+		     _("malformed context diff at line %ld"), line_number);
 	    }
 
 	  if (old_line > old_last)
